==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Cliente"

, "State"
: "Estado"

, "Role"
: "Cargo"

, "Source"
: "Fuente"

, "Start"
: "Inicio"

, "Scheduled end"
: "Programación finalizada"

, "End"
: "Fin"

, "Turnover"
: "Facturación"

, "Probability"
: "Probabilidad"

, "Folder"
: "Carpeta"

, "Updated by"
: "Actualizado por"

, "Updated Fields:"
: "Campos Actualizados:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "Etiquetas"

, "Lead %s has been changed"
: "Iniciativa %s ha sido cambiada"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Iniciativa %s ha sido creada"

, "Lead Data"
: "Fecha Iniciativa"

, "Leadstate"
: "Estado Iniciativa"

, "Leadtype"
: "Tipo de Iniciativa"

, "Leadsource"
: "Fuente de la Iniciativa"

, "End Scheduled"
: "Programación Finalizada"

, "Contacts"
: "Contactos"

, "Address"
: "Dirección"

, "Telephone"
: "Teléfono"

, "Email"
: "Email"

, "Tasks"
: "Tareas"

, "Due Date"
: "Fecha Apta"

, "Priority"
: "Prioridad"

, "Products"
: "Productos"

, "low"
: "baja"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgente"

, "All leads I have read grants for"
: "Todas las iniciativas leídas aplican para"

, "Last modified by me"
: "Últimas modificadas por mi"

, "All leads that I have last modified"
: "Todas las iniciativas modificadas últimamente"

, "My leads"
: "Mis iniciativas"

, "All leads that I am responsible for"
: "Todas las iniciativas de mi responsabilidad para"

, "Leads with overdue tasks"
: "Iniciativas con retraso"

, "All leads"
: "Todas las iniciativas"

, "Default Lead List"
: "Lista de iniciativas por defecto"

, "The default list for new leads"
: "Lista por defecto para nuevas iniciativas"

, "Get Notification Emails"
: "Obtener Notificación por Emails"

, "The level of actions you want to be notified about."
: "El nivel de las acciones a notificar."

, "Send Notifications Emails for own actions"
: "Enviar Emails de Notificación de las Acciones propias"

, "Get notifications emails for actions you did yourself"
: "Obtener emails de notificación de las acciones que usted hizo"

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on crm startup"
: "El favorito por defecto que se carga al comienzo de CRM"

, "manage shared lead folders"
: "gestionar carpetas compartidas de iniciativas"

, "Create new shared lead folders"
: "Crear nueva carpeta compartida de iniciativas"

, "manage shared leads favorites"
: "gestionar iniciativas favoritas compartidas"

, "Create or update shared leads favorites"
: "Crear o actualizar iniciativas favoritas compartidas"

, "Contact"
: "Contacto"

, "CRM Role"
: "Cargo CRM"

, "Lead, Leads"
: [
  "Iniciativa"
 ,"Iniciativas"

]
, "lead list, lead lists"
: [
  "Lista de iniciativas"
 ,"Listados de iniciativas"

]
, "lead lists"
: "Listados de iniciativas"

, "Quick Search"
: "Búsqueda Rápida"

, "Lead name"
: "Nombre de la Iniciativa"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creado por"

, "Estimated end"
: "Estimación finaliza"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Socio"

, "Phone"
: "Teléfono"

, "Mobile"
: "Móvil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Estado"

, "Change type to Customer"
: "Cambiar de cliente"

, "Responsible"
: "Responsable"

, "Change type to Responsible"
: "Cambiar de Responsable"

, "Change type to Partner"
: "Cambiar de Socio"

, "Change contact type"
: "Cambiar tipo de contacto"

, "Search for Contacts to add ..."
: "Buscar contactos para añadir... "

, "Name"
: "Nombre"

, "Data"
: "Fecha"

, "Cellphone"
: "Teléfono móvil"

, "Add new {0}"
: "Agregar nueva {0}"

, "Unlink {0}"
: "Desconectar {0}"

, "Unlink selected {0}"
: "Desconectar selecccionados {0}"

, "Edit {0}"
: "Editar {0}"

, "Edit selected {0}"
: "Editar seleccionados {0}"

, "No Tasks to display"
: "No hay tareas que mostar"

, "Summary"
: "Resumen"

, "Add a task..."
: "Agregar una tarea..."

, "Percent"
: "Porcentaje"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: "Ingresar referencia para agregar los contactos"

, "Please select the attenders' role"
: "Seleccione rol de asistentes"

, "Select Lead"
: "Seleccionar iniciativa"

, "Select Role"
: "Seleccionar Cargo"

, "Adding {0} contacts to lead"
: "Agregar {0} contactos a la iniciativa"

, "Probable Turnover"
: "Facturación Prevista"

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: "No tiene privilegios para ejecutar la aplicación Tareas o no esta activada."

, "You do not have the run right for the Sales application or it is not activated."
: "No tiene privilegios para ejecutar la aplicación Ventas o no esta activada."

, "Enter lead name"
: ""

, "Expected turnover"
: "Facturación anual"

, "Description"
: "Descripción"

, "Enter description"
: "Escribir descripción"

, "New Lead"
: "Nueva Iniciativa"

, "Product"
: "Producto"

, "Price"
: "Precio"

, "Quantity"
: "Cantidad"

, "Search for Products to add ..."
: "Buscar Productos para añadir ..."

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: "Tarea"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "abierto"

, "contacted"
: "contactado"

, "waiting for feedback"
: "esperando respuesta"

, "quote sent"
: "propuesta enviada"

, "accepted"
: "aceptado"

, "lost"
: "perdido"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Distribuidor"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: "Iniciativa"

, "lead list"
: "Lista de iniciativas"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Todas las iniciativas"

, "Default Lead List"
: "Lista de iniciativas por defecto"

, "The default list for new leads"
: "Lista por defecto para nuevas iniciativas"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "El nivel de las acciones a notificar."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Favorito por defecto"

, "The default favorite which is loaded on crm startup"
: "El favorito por defecto que se carga al comienzo de CRM"

, "New Lead"
: "Nueva Iniciativa"

, "Tags"
: "Etiquetas"

, "Lead name"
: "Nombre de la Iniciativa"

, "Responsible"
: "Responsable"

, "Partner"
: "Socio"

, "Customer"
: "Cliente"

, "Leadstate"
: "Estado Iniciativa"

, "Leadtype"
: "Tipo de Iniciativa"

, "Leadsource"
: "Fuente de la Iniciativa"

, "Probability"
: "Probabilidad"

, "Turnover"
: "Facturación"

, "Estimated end"
: "Estimación finaliza"

, "Probable Turnover"
: "Facturación Prevista"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Contacto"

, "CRM Role"
: "Cargo CRM"

, "Tasks"
: "Tareas"

, "No Tasks to display"
: "No hay tareas que mostar"

, "Summary"
: "Resumen"

, "Add a task..."
: "Agregar una tarea..."

, "Due Date"
: "Fecha Apta"

, "Priority"
: "Prioridad"

, "Percent"
: "Porcentaje"

, "Status"
: "Estado"

, "Organizer"
: ""

, "Add new {0}"
: "Agregar nueva {0}"

, "Unlink {0}"
: "Desconectar {0}"

, "Unlink selected {0}"
: "Desconectar selecccionados {0}"

, "Edit {0}"
: "Editar {0}"

, "Edit selected {0}"
: "Editar seleccionados {0}"

, "Please choose the Lead to add the contacts to"
: "Ingresar referencia para agregar los contactos"

, "Please select the attenders' role"
: "Seleccione rol de asistentes"

, "Lead, Leads"
: [
  "Iniciativa"
 ,"Iniciativas"

]
, "Select Lead"
: "Seleccionar iniciativa"

, "Role"
: "Cargo"

, "Select Role"
: "Seleccionar Cargo"

, "Adding {0} contacts to lead"
: "Agregar {0} contactos a la iniciativa"

, "Phone"
: "Teléfono"

, "Mobile"
: "Móvil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Inicio"

, "Change type to Customer"
: "Cambiar de cliente"

, "Change type to Responsible"
: "Cambiar de Responsable"

, "Change type to Partner"
: "Cambiar de Socio"

, "Change contact type"
: "Cambiar tipo de contacto"

, "Search for Contacts to add ..."
: "Buscar contactos para añadir... "

, "Name"
: "Nombre"

, "Address"
: "Dirección"

, "Data"
: "Fecha"

, "Cellphone"
: "Teléfono móvil"

, "End"
: "Fin"

, "You do not have the run right for the Tasks application or it is not activated."
: "No tiene privilegios para ejecutar la aplicación Tareas o no esta activada."

, "Products"
: "Productos"

, "You do not have the run right for the Sales application or it is not activated."
: "No tiene privilegios para ejecutar la aplicación Ventas o no esta activada."

, "Enter lead name"
: ""

, "Expected turnover"
: "Facturación anual"

, "Description"
: "Descripción"

, "Enter description"
: "Escribir descripción"

, "lead list, lead lists"
: [
  "Lista de iniciativas"
 ,"Listados de iniciativas"

]
, "lead lists"
: "Listados de iniciativas"

, "Quick Search"
: "Búsqueda Rápida"

, "Last Modified Time"
: "Fecha última modificación"

, "Last Modified By"
: "Última modificación por"

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: "Creado por"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Producto"

, "Price"
: "Precio"

, "Quantity"
: "Cantidad"

, "Search for Products to add ..."
: "Buscar Productos para añadir ..."

, "All leads I have read grants for"
: "Todas las iniciativas leídas aplican para"

, "Last modified by me"
: "Últimas modificadas por mi"

, "All leads that I have last modified"
: "Todas las iniciativas modificadas últimamente"

, "My leads"
: "Mis iniciativas"

, "All leads that I am responsible for"
: "Todas las iniciativas de mi responsabilidad para"

, "Leads with overdue tasks"
: "Iniciativas con retraso"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "abierto"

, "contacted"
: "contactado"

, "waiting for feedback"
: "esperando respuesta"

, "quote sent"
: "propuesta enviada"

, "accepted"
: "aceptado"

, "lost"
: "perdido"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Distribuidor"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Estado"

, "Source"
: "Fuente"

, "Scheduled end"
: "Programación finalizada"

, "Folder"
: "Carpeta"

, "Updated by"
: "Actualizado por"

, "Updated Fields:"
: "Campos Actualizados:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Iniciativa %s ha sido cambiada"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Iniciativa %s ha sido creada"

, "Task"
: "Tarea"

, "Lead Data"
: "Fecha Iniciativa"

, "End Scheduled"
: "Programación Finalizada"

, "Contacts"
: "Contactos"

, "Telephone"
: "Teléfono"

, "Email"
: "Email"

, "low"
: "baja"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgente"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "gestionar carpetas compartidas de iniciativas"

, "Create new shared lead folders"
: "Crear nueva carpeta compartida de iniciativas"

, "manage shared leads favorites"
: "gestionar iniciativas favoritas compartidas"

, "Create or update shared leads favorites"
: "Crear o actualizar iniciativas favoritas compartidas"




, "Lead"
: "Iniciativa"

, "lead list"
: "Lista de iniciativas"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
